==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/nb_NO.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Henting av henvendelsessymboler feilet. Sjekk at app-nøkkelen og hemmeligheten din stemmer.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Henting av adgangssymboler feilet. Sjekk at app-nøkkelen og hemmeligheten din stemmer.",
    "Please provide a valid app key and secret." : "Vær vennlig å oppgi gyldig appnøkkel og hemmelighet.",
    "Step 1 failed. Exception: %s" : "Steg 1 feilet. Unntak: %s",
    "Step 2 failed. Exception: %s" : "Steg 2 feilet. Unntak: %s",
    "External storage" : "Ekstern lagringsplass",
    "Storage with id \"%i\" not found" : "Lager med id \"%i\" ikke funnet",
    "Invalid backend or authentication mechanism class" : "Ugyldig server eller type autentiseringsmekanisme",
    "Invalid mount point" : "Ugyldig oppkoblingspunkt",
    "Objectstore forbidden" : "Objektlager forbudt",
    "Invalid storage backend \"%s\"" : "Ugyldig lagringsserver \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ikke tillatt å bruke server \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ikke tillatt å bruke autentiseringsmekanisme \"%s\"",
    "Unsatisfied backend parameters" : "Noen server-parameter mangler",
    "Unsatisfied authentication mechanism parameters" : "Noen parametre for autentiseringsmekanisme mangler",
    "Personal" : "Personlig",
    "System" : "System",
    "Grant access" : "Gi tilgang",
    "Access granted" : "Tilgang innvilget",
    "Error configuring OAuth1" : "Feil ved konfigurering av OAuth1",
    "Error configuring OAuth2" : "Feil ved konfigurering av OAuth2",
    "Generate keys" : "Generer nøkler",
    "Error generating key pair" : "Feil ved nøkkelgenerering",
    "Enable encryption" : "Aktiver kryptering",
    "Enable previews" : "Tillat fohåndsvisning",
    "Check for changes" : "Se etter endringer",
    "Never" : "Aldri",
    "Once every direct access" : "En gang pr. direkte aksess",
    "Every time the filesystem is used" : "Hver gang filsystemet brukes",
    "All users. Type to select user or group." : "Alle brukere. Tast for å velge bruker eller gruppe.",
    "(group)" : "(gruppe)",
    "Saved" : "Lagret",
    "Access key" : "Tilgangsnøkkel",
    "Secret key" : "Hemmelig nøkkel",
    "Builtin" : "Innebygget",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Username" : "Brukernavn",
    "Password" : "Passord",
    "Tenant name" : "Prosjektnavn",
    "Identity endpoint URL" : "URL for identitets-endepunkt",
    "Rackspace" : "Rackspace",
    "API key" : "API-nøkkel",
    "Username and password" : "Brukernavn og passord",
    "Session credentials" : "Påloggingsdetaljer for økt",
    "RSA public key" : "RSA offentlig nøkkel",
    "Public key" : "Offentlig nøkkel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Servernavn",
    "Port" : "Port",
    "Region" : "Området",
    "Enable SSL" : "Aktiver SSL",
    "Enable Path Style" : "Aktiver Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Ekstern undermappe",
    "Secure https://" : "Sikker https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Tjener",
    "Secure ftps://" : "Sikker ftps://",
    "Google Drive" : "Google Disk",
    "Local" : "Lokal",
    "Location" : "Sted",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Rot",
    "SFTP with secret key login" : "SFTP med hemmelig nøkkel for pålogging",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Delt ressurs",
    "Domain" : "Domene",
    "SMB / CIFS using OC login" : "SMB / CIFS med OC-pålogging",
    "Username as share" : "Brukernavn som share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Tjenestenavn",
    "Request timeout (seconds)" : "Tidsavbrudd for forespørsel (sekunder)",
    "<b>Note:</b> " : "<b>Merk:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> Støtte for cURL i PHP er ikke aktivert eller installert. Oppkobling av %s er ikke mulig. Be systemadministratoren om å installere det.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> FTP-støtte i PHP er ikke slått på eller installert. Kan ikke koble opp %s. Ta kontakt med systemadministratoren for å få dette installert.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> \"%s\" er ikke installert. Oppkobling av %s er ikke mulig. Spør systemadministratoren om å installere det.",
    "No external storage configured" : "Eksternt lager er ikke konfigurert",
    "You can add external storages in the personal settings" : "Du kan legge til eksterne lagre i personlige innstillinger",
    "Name" : "Navn",
    "Storage type" : "Lagringstype",
    "Scope" : "Omfang",
    "External Storage" : "Ekstern lagring",
    "Folder name" : "Mappenavn",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfigurasjon",
    "Available for" : "Tilgjengelig for",
    "Advanced settings" : "Avanserte innstillinger",
    "Delete" : "Slett",
    "Add storage" : "Legg til lagringsplass",
    "Enable User External Storage" : "Aktiver ekstern lagring for bruker",
    "Allow users to mount the following external storage" : "Tillat brukere å koble opp følgende eksterne lagring"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/nb_NO.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Henting av henvendelsessymboler feilet. Sjekk at app-nøkkelen og hemmeligheten din stemmer.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Henting av adgangssymboler feilet. Sjekk at app-nøkkelen og hemmeligheten din stemmer.",
    "Please provide a valid app key and secret." : "Vær vennlig å oppgi gyldig appnøkkel og hemmelighet.",
    "Step 1 failed. Exception: %s" : "Steg 1 feilet. Unntak: %s",
    "Step 2 failed. Exception: %s" : "Steg 2 feilet. Unntak: %s",
    "External storage" : "Ekstern lagringsplass",
    "Storage with id \"%i\" not found" : "Lager med id \"%i\" ikke funnet",
    "Invalid backend or authentication mechanism class" : "Ugyldig server eller type autentiseringsmekanisme",
    "Invalid mount point" : "Ugyldig oppkoblingspunkt",
    "Objectstore forbidden" : "Objektlager forbudt",
    "Invalid storage backend \"%s\"" : "Ugyldig lagringsserver \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ikke tillatt å bruke server \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ikke tillatt å bruke autentiseringsmekanisme \"%s\"",
    "Unsatisfied backend parameters" : "Noen server-parameter mangler",
    "Unsatisfied authentication mechanism parameters" : "Noen parametre for autentiseringsmekanisme mangler",
    "Insufficient data: %s" : "Utilstrekkelige data: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Lager med id \"%i\" kan ikke redigeres av bruker",
    "Personal" : "Personlig",
    "System" : "System",
    "Grant access" : "Gi tilgang",
    "Access granted" : "Tilgang innvilget",
    "Error configuring OAuth1" : "Feil ved konfigurering av OAuth1",
    "Error configuring OAuth2" : "Feil ved konfigurering av OAuth2",
    "Generate keys" : "Generer nøkler",
    "Error generating key pair" : "Feil ved nøkkelgenerering",
    "Enable encryption" : "Aktiver kryptering",
    "Enable previews" : "Tillat fohåndsvisning",
    "Enable sharing" : "Aktiver deling",
    "Check for changes" : "Se etter endringer",
    "Never" : "Aldri",
    "Once every direct access" : "En gang pr. direkte aksess",
    "All users. Type to select user or group." : "Alle brukere. Tast for å velge bruker eller gruppe.",
    "(group)" : "(gruppe)",
    "Admin defined" : "Admin-definert",
    "Saved" : "Lagret",
    "Empty response from the server" : "Tomt svar fra serveren",
    "Couldn't access. Please logout and login to activate this mount point" : "Fikk ikke tilgang. Vennligst logg ut og inn igjen for å aktivere dette oppkoblingspunktet.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Klarte ikke å hente informasjon fra ownCloud-serveren: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Klarte ikke å hente listen over eksterne oppkoblingspunkter: {type}",
    "There was an error with message: " : "Det oppstod en feil med melding: ",
    "External mount error" : "Ekstern oppkoblingsfeil",
    "external-storage" : "eksternlagring",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Klarte ikke å hente listen over oppkoblingspunkter for Windows nettverk-disker: tomt svar fra serveren",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Noen av de konfigurerte eksterne oppkoblingspunktene er ikke tilkoblet. Klikk på de røde raden(e) for mer informasjon.",
    "Please enter the credentials for the {mount} mount" : "Legg inn påloggingsdetaljer for {mount}",
    "Username" : "Brukernavn",
    "Password" : "Passord",
    "Credentials saved" : "Påloggingsdetaljer lagret",
    "Credentials saving failed" : "Lagring av påloggingsdetaljer feilet",
    "Credentials required" : "Påloggingsdetaljer kreves",
    "Save" : "Lagre",
    "Access key" : "Tilgangsnøkkel",
    "Secret key" : "Hemmelig nøkkel",
    "Builtin" : "Innebygget",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Prosjektnavn",
    "Identity endpoint URL" : "URL for identitets-endepunkt",
    "Rackspace" : "Rackspace",
    "API key" : "API-nøkkel",
    "Username and password" : "Brukernavn og passord",
    "Log-in credentials, save in session" : "Påloggingsdetaljer, lagre i økten",
    "RSA public key" : "RSA offentlig nøkkel",
    "Public key" : "Offentlig nøkkel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Servernavn",
    "Port" : "Port",
    "Region" : "Området",
    "Enable SSL" : "Aktiver SSL",
    "Enable Path Style" : "Aktiver Path Style",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Ekstern undermappe",
    "Secure https://" : "Sikker https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Tjener",
    "Secure ftps://" : "Sikker ftps://",
    "Google Drive" : "Google Disk",
    "Local" : "Lokal",
    "Location" : "Sted",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Rot",
    "SFTP with secret key login" : "SFTP med hemmelig nøkkel for pålogging",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Delt ressurs",
    "Domain" : "Domene",
    "SMB / CIFS using OC login" : "SMB / CIFS med OC-pålogging",
    "Username as share" : "Brukernavn som share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Tjenestenavn",
    "Request timeout (seconds)" : "Tidsavbrudd for forespørsel (sekunder)",
    "<b>Note:</b> " : "<b>Merk:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> Støtte for cURL i PHP er ikke aktivert eller installert. Oppkobling av %s er ikke mulig. Be systemadministratoren om å installere det.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> FTP-støtte i PHP er ikke slått på eller installert. Kan ikke koble opp %s. Ta kontakt med systemadministratoren for å få dette installert.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Merk:</b> \"%s\" er ikke installert. Oppkobling av %s er ikke mulig. Spør systemadministratoren om å installere det.",
    "No external storage configured" : "Eksternt lager er ikke konfigurert",
    "You can add external storages in the personal settings" : "Du kan legge til eksterne lagre i personlige innstillinger",
    "Name" : "Navn",
    "Storage type" : "Lagringstype",
    "Scope" : "Omfang",
    "External Storage" : "Ekstern lagring",
    "Folder name" : "Mappenavn",
    "Authentication" : "Autentisering",
    "Configuration" : "Konfigurasjon",
    "Available for" : "Tilgjengelig for",
    "Add storage" : "Legg til lagringsplass",
    "Advanced settings" : "Avanserte innstillinger",
    "Delete" : "Slett",
    "Allow users to mount external storage" : "Tillat at brukere kobler opp eksterne lagre",
    "Allow users to mount the following external storage" : "Tillat brukere å koble opp følgende eksterne lagring"
},
"nplurals=2; plural=(n != 1);");
